summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorZiad Sawalha <github@highbridgellc.com>2011-12-02 09:29:45 -0600
committerZiad Sawalha <github@highbridgellc.com>2011-12-02 09:29:55 -0600
commitdb9c53e5f54a5e8c9f0170180a8fc1673d030bbf (patch)
tree5d980dbe83ac6c01bd588aa9ba6ae3b33db4a29b
parent5c70d24462d75256fb6167d58e13d9c0a3d60427 (diff)
Deprecating RAX-KEY middleware
This middleware was never fully functional and has now been deprecated. To not break existing configurations, the middleware is still there and will do nothing except show a message that it will be removed in Essex+1 to give ample notice for removing it from configurations. It has also been removed from all configuration files. The functionality will be provided using the new extension framework. Also discovered OS-EC2 middleware was copy/paste named RAX-KEY also and fixed that Change-Id: I518baaf88a70b2b4a6f7a1038e30b256a3812f09
-rw-r--r--etc/keystone.conf4
-rw-r--r--keystone/contrib/extensions/service/osec2/frontend.py2
-rw-r--r--keystone/contrib/extensions/service/raxkey/frontend.py13
-rw-r--r--keystone/test/etc/ldap.conf.template4
-rw-r--r--keystone/test/etc/memcache.conf.template4
-rw-r--r--keystone/test/etc/sql.conf.template4
-rw-r--r--keystone/test/etc/ssl.conf.template4
7 files changed, 10 insertions, 25 deletions
diff --git a/etc/keystone.conf b/etc/keystone.conf
index 075f2ffd..05a369ea 100644
--- a/etc/keystone.conf
+++ b/etc/keystone.conf
@@ -96,7 +96,6 @@ pipeline =
pipeline =
urlrewritefilter
legacy_auth
- RAX-KEY-extension
service_api
[app:service_api]
@@ -111,8 +110,5 @@ paste.filter_factory = keystone.middleware.url:filter_factory
[filter:legacy_auth]
paste.filter_factory = keystone.frontends.legacy_token_auth:filter_factory
-[filter:RAX-KEY-extension]
-paste.filter_factory = keystone.contrib.extensions.service.raxkey.frontend:filter_factory
-
[filter:debug]
paste.filter_factory = keystone.common.wsgi:debug_filter_factory
diff --git a/keystone/contrib/extensions/service/osec2/frontend.py b/keystone/contrib/extensions/service/osec2/frontend.py
index c461466a..3f369d45 100644
--- a/keystone/contrib/extensions/service/osec2/frontend.py
+++ b/keystone/contrib/extensions/service/osec2/frontend.py
@@ -29,7 +29,7 @@ import json
from lxml import etree
from webob.exc import Request, Response
-EXTENSION_ALIAS = "RAX-KEY"
+EXTENSION_ALIAS = "OS-EC2"
class FrontEndFilter(object):
diff --git a/keystone/test/etc/ldap.conf.template b/keystone/test/etc/ldap.conf.template
index 46d251cc..61211381 100644
--- a/keystone/test/etc/ldap.conf.template
+++ b/keystone/test/etc/ldap.conf.template
@@ -40,7 +40,6 @@ pipeline =
pipeline =
urlrewritefilter
legacy_auth
- RAX-KEY-extension
service_api
[app:service_api]
@@ -54,6 +53,3 @@ paste.filter_factory = keystone.middleware.url:filter_factory
[filter:legacy_auth]
paste.filter_factory = keystone.frontends.legacy_token_auth:filter_factory
-
-[filter:RAX-KEY-extension]
-paste.filter_factory = keystone.contrib.extensions.service.raxkey.frontend:filter_factory
diff --git a/keystone/test/etc/memcache.conf.template b/keystone/test/etc/memcache.conf.template
index e3fc3639..b3f94e97 100644
--- a/keystone/test/etc/memcache.conf.template
+++ b/keystone/test/etc/memcache.conf.template
@@ -38,7 +38,6 @@ pipeline =
pipeline =
urlrewritefilter
legacy_auth
- RAX-KEY-extension
service_api
[app:service_api]
@@ -52,6 +51,3 @@ paste.filter_factory = keystone.middleware.url:filter_factory
[filter:legacy_auth]
paste.filter_factory = keystone.frontends.legacy_token_auth:filter_factory
-
-[filter:RAX-KEY-extension]
-paste.filter_factory = keystone.contrib.extensions.service.raxkey.frontend:filter_factory
diff --git a/keystone/test/etc/sql.conf.template b/keystone/test/etc/sql.conf.template
index 5085accd..1ec45cde 100644
--- a/keystone/test/etc/sql.conf.template
+++ b/keystone/test/etc/sql.conf.template
@@ -34,7 +34,6 @@ pipeline =
pipeline =
urlrewritefilter
legacy_auth
- RAX-KEY-extension
service_api
[app:service_api]
@@ -48,6 +47,3 @@ paste.filter_factory = keystone.middleware.url:filter_factory
[filter:legacy_auth]
paste.filter_factory = keystone.frontends.legacy_token_auth:filter_factory
-
-[filter:RAX-KEY-extension]
-paste.filter_factory = keystone.contrib.extensions.service.raxkey.frontend:filter_factory
diff --git a/keystone/test/etc/ssl.conf.template b/keystone/test/etc/ssl.conf.template
index 4eb4b922..62d867c4 100644
--- a/keystone/test/etc/ssl.conf.template
+++ b/keystone/test/etc/ssl.conf.template
@@ -37,7 +37,6 @@ pipeline =
pipeline =
urlrewritefilter
legacy_auth
- RAX-KEY-extension
service_api
[app:service_api]
@@ -51,6 +50,3 @@ paste.filter_factory = keystone.middleware.url:filter_factory
[filter:legacy_auth]
paste.filter_factory = keystone.frontends.legacy_token_auth:filter_factory
-
-[filter:RAX-KEY-extension]
-paste.filter_factory = keystone.contrib.extensions.service.raxkey.frontend:filter_factory
diff --git a/keystone/contrib/extensions/service/raxkey/frontend.py b/keystone/contrib/extensions/service/raxkey/frontend.py
index bd203b78..8d4f9edf 100644
--- a/keystone/contrib/extensions/service/raxkey/frontend.py
+++ b/keystone/contrib/extensions/service/raxkey/frontend.py
@@ -19,7 +19,10 @@
"""
RACKSPACE API KEY EXTENSION
-Soon to be deprecated middleware.
+Deprecated middleware. We still have it here to not break compatiblity with
+configuration files that add it to the pipeline.
+
+TODO(ZNS): Remove this in Essex+1
"""
import logging
@@ -38,9 +41,11 @@ class FrontEndFilter(object):
self.app = app
def __call__(self, env, start_response):
- LOG.warn('This middleware is soon to be deprecated." +\
- "Please remove related entries from conf files.')
- #Kept for backward compatibility.Does nothing as of now.
+ LOG.warn("%s middleware is deprecated and will be removed in "
+ "Essex+1 (Fall fo 2012). Remove it from your "
+ "configuration files." % EXTENSION_ALIAS)
+ #Kept for backward compatibility with existing configuration files.
+ #Does nothing now.
return self.app(env, start_response)